"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const index_1 = require("../index");
const clientCookieManager_1 = require("./clientCookieManager");
require("../constants/lang");
class Client {
    /**
     * @param {Object} options - The options to use.
     */
    constructor(options) {
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "DailyReward", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "GameRecordCard", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "SprialAbyss", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "GenshinActivity", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "Characters", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "GenshinUser", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "RealTimeNotes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "TravelDiary", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.options = {
            language: (options === null || options === void 0 ? void 0 : options.language) || "en-us" /* Language.EnglishUS */,
            cookieManager: (options === null || options === void 0 ? void 0 : options.cookieManager) || new clientCookieManager_1.ClientCookieManager(),
            cache: (options === null || options === void 0 ? void 0 : options.cache) || false,
        };
        this.cookieManager = this.options.cookieManager;
        this.DailyReward = new index_1.DailyRewards();
        this.GenshinActivity = new index_1.Activities({ cache: this.options.cache });
        this.GameRecordCard = new index_1.GameRecordCard({ cache: this.options.cache });
        this.SprialAbyss = new index_1.SpiralAbyss({ cache: this.options.cache });
        this.GenshinUser = new index_1.GenshinUser({ cache: this.options.cache });
        this.RealTimeNotes = new index_1.RealTimeNotes({ cache: this.options.cache });
        this.Characters = new index_1.Charcters({ cache: this.options.cache });
        this.TravelDiary = new index_1.TravelerDiary({ cache: this.options.cache });
    }
    setltoken(ltoken) {
        this.cookieManager.setltoken(ltoken);
    }
    setltuid(ltuid) {
        this.cookieManager.setltuid(ltuid);
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getAbyssBattle(uid, previous) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.SprialAbyss.fetch(uid, language, cookie, previous);
        return res;
    }
    /**
     * @param {string} uid - HoYolab uid.
     */
    async getGameRecordCard(uid) {
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.GameRecordCard.fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getGenshinUser(uid) {
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.GenshinUser.fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getRealTimeNotes(uid) {
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.RealTimeNotes.fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getCharacter(uid) {
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.Characters.fetch(uid, language, cookie);
        return res;
    }
    /**
     *  @param {string} uid - Genshin Impact game uid.
     */
    async getTravelDiary(uid) {
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = this.TravelDiary.fetch(uid, language, cookie);
        return res;
    }
}
exports.Client = Client;
