"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientCookieManager = void 0;
const cookieFormatter_1 = require("../utils/cookieFormatter");
class ClientCookieManager {
    constructor() {
        Object.defineProperty(this, "cookie", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cookie = {
            ltoken: [],
            ltuid: [],
        };
    }
    /**
     * @returns {number} - The amount of cookies.
     */
    amount() {
        if (this.cookie.ltoken.length !== this.cookie.ltuid.length) {
            throw new Error("Invalid cookie");
        }
        return this.cookie.ltoken.length;
    }
    setltoken(ltoken) {
        this.cookie.ltoken.push(ltoken);
    }
    setltuid(ltuid) {
        this.cookie.ltuid.push(ltuid);
    }
    /**
     * @description Get the ltoken and ltuid for request.
     * @returns {Object} - The ltoken and ltuid.
     */
    get() {
        if (this.amount() === 0) {
            throw new Error("Please login first.");
        }
        if (this.amount() === 1) {
            if (!this.cookie.ltoken[0] || !this.cookie.ltuid[0]) {
                throw new Error("Invalid cookie");
            }
            return {
                ltoken: this.cookie.ltoken[0],
                ltuid: this.cookie.ltuid[0],
                key: 0,
                cookie: (0, cookieFormatter_1.CookieFormatter)(this.cookie.ltoken[0], this.cookie.ltuid[0]),
            };
        }
        const ltoken = this.cookie.ltoken[0];
        const ltuid = this.cookie.ltuid[0];
        if (!ltoken || !ltuid) {
            throw new Error("Invalid cookie");
        }
        this.cookie.ltoken.splice(0, 1);
        this.cookie.ltuid.splice(0, 1);
        this.cookie.ltoken.push(ltoken);
        this.cookie.ltuid.push(ltuid);
        return {
            ltoken: ltoken,
            ltuid: ltuid,
            key: this.amount() - 1,
            cookie: (0, cookieFormatter_1.CookieFormatter)(ltoken, ltuid),
        };
    }
    /**
     * @param key - The key to remove.
     */
    delete(key) {
        this.cookie.ltoken.splice(key, 1);
        this.cookie.ltuid.splice(key, 1);
    }
    clear() {
        this.cookie.ltoken = [];
        this.cookie.ltuid = [];
    }
    getAll() {
        const cookie = {};
        for (let i = 0; i < this.amount(); i++) {
            cookie[i] = {
                ltoken: this.cookie.ltoken[i],
                ltuid: this.cookie.ltuid[i],
            };
        }
        return cookie;
    }
}
exports.ClientCookieManager = ClientCookieManager;
