import type { ClaimHistoryData, DailyRewardsData, DayRewardData, ExtraRewardData, ResignData, RewardInfoData } from "../interface";
import type { Language } from "../constants/lang";
export declare class DailyRewards {
    /**
     * @description Get the daily rewards details
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     * @param {number} day get the day's rewards
     */
    getDayReward(day: number, language: Language, cookie: string): Promise<DayRewardData>;
    /**
     *
     * @description Claim the daily rewards
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    claim(language: Language, cookie: string): Promise<DailyRewardsData>;
    /**
     * @description Get the daily rewards info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    fetchRewardInfo(language: Language, cookie: string): Promise<RewardInfoData>;
    /**
     * @description Get the extra rewards info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    fetchExtraRewardInfo(cookie: string): Promise<ExtraRewardData>;
    /**
     * @description get resign info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    fetchResignInfo(language: Language, cookie: string): Promise<ResignData>;
    /**
     * @description get claim history
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     * @param {number | undefined} page The page to set
     */
    fetchClaimHistory(language: Language, cookie: string, page?: number): Promise<ClaimHistoryData>;
}
