"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DailyRewards = void 0;
const request_1 = require("../utils/request");
const constants_1 = require("../constants/constants");
const alias_1 = require("../utils/alias");
class DailyRewards {
    /**
     * @description Get the daily rewards details
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     * @param {number} day get the day's rewards
     */
    async getDayReward(day, language, cookie) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
        });
        instance.setLanguage(language);
        const res = await instance.get("home", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        return (0, alias_1.alias)(data.awards[day - 1], { cnt: "count" });
    }
    /**
     *
     * @description Claim the daily rewards
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    async claim(language, cookie) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
            withUA: true,
        });
        const res = await instance.post("sign", {
            Cookie: cookie,
            "Content-Type": "application/json",
        }, {
            act_id: "e202102251931481",
        }, {
            lang: language,
        });
        if (res.retcode === -5003) {
            return {
                status: "Already claimed",
                code: -5003,
                rewards: null,
            };
        }
        if (res.data.code === "ok" && res.retcode === 0) {
            const info = await this.fetchRewardInfo(language, cookie);
            const today = info.today.split("-")[2];
            const reward = await this.getDayReward(parseInt(today), language, cookie);
            return {
                status: "success",
                code: 0,
                rewards: reward,
            };
        }
        return {
            status: "error",
            code: res.retcode,
            rewards: null,
        };
    }
    /**
     * @description Get the daily rewards info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    async fetchRewardInfo(language, cookie) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
        });
        instance.setLanguage(language);
        const res = await instance.get("info", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        return data;
    }
    /**
     * @description Get the extra rewards info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    async fetchExtraRewardInfo(cookie) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
        });
        const res = await instance.get("extra_award", {
            Cookie: cookie,
        }, {
            act_id: "e202102251931481",
            region: "",
            uid: "",
        });
        const { data } = res;
        (0, alias_1.alias)(data, { total_cnt: "total_count" });
        for (const award of data.awards) {
            (0, alias_1.alias)(award, { cnt: "count" });
        }
        return data;
    }
    /**
     * @description get resign info
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     */
    async fetchResignInfo(language, cookie) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
        });
        instance.setLanguage(language);
        const res = await instance.get("resign_info", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        (0, alias_1.alias)(data, {
            resign_cnt_daily: "resign_count_daily",
            resign_cnt_monthly: "resign_count_monthly",
            sign_cnt_missed: "sign_count_missed",
            quality_cnt: "quality_count",
            sign_cnt: "sign_count",
            month_quality_cnt: "month_quality_count",
        });
        return data;
    }
    /**
     * @description get claim history
     * @param {string} cookie The cookie to set
     * @param {Language} language The language to set
     * @param {number | undefined} page The page to set
     */
    async fetchClaimHistory(language, cookie, page) {
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_REWARD_URL,
        });
        instance.setLanguage(language);
        const res = await instance.get("award", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
            current_page: page || 1,
            page_size: 10,
        });
        const { data } = res;
        for (const award of data.list) {
            (0, alias_1.alias)(award, { cnt: "count" });
        }
        return data;
    }
}
exports.DailyRewards = DailyRewards;
