"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.request = void 0;
const tslib_1 = require("tslib");
const constants_1 = require("../constants/constants");
const undici_1 = require("undici");
const generate_ds_1 = tslib_1.__importDefault(require("./generate_ds"));
const error_1 = require("./error");
const error_2 = tslib_1.__importDefault(require("../constants/error"));
/**
 * @description Creates a new instance for the request
 */
class HTTPRequest {
    constructor(option) {
        Object.defineProperty(this, "baseURL", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "withUA", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "withDS", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "language", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.baseURL = constants_1.Genshin_Battle_API_URL;
        if (option === null || option === void 0 ? void 0 : option.route) {
            this.baseURL = option.route;
        }
        this.withUA = (option === null || option === void 0 ? void 0 : option.withUA) || false;
        this.withDS = (option === null || option === void 0 ? void 0 : option.withDS) || false;
        this.language = "en-us";
    }
    async get(url, headers, params) {
        const { body: res, statusCode } = await (0, undici_1.request)(`${this.baseURL}${url}`, {
            method: "GET",
            headers: {
                "User-Agent": this.withUA ? constants_1.UA : undefined,
                "x-rpc-language": this.language,
                DS: this.withDS ? (0, generate_ds_1.default)() : undefined,
                ...headers,
            },
            query: params,
        });
        if (statusCode !== 200) {
            throw new Error(`Request failed with status code ${statusCode}`);
        }
        const resData = await res.json();
        if (resData.retcode !== 0) {
            const description = (0, error_2.default)(resData.retcode);
            throw new error_1.APIERROR(`${resData.message}`, resData.retcode, description);
        }
        return resData;
    }
    async post(url, headers, data, params) {
        const { body: res, statusCode } = await (0, undici_1.request)(`${this.baseURL}${url}`, {
            method: "POST",
            headers: {
                "User-Agent": this.withUA ? constants_1.UA : undefined,
                "x-rpc-language": this.language,
                DS: this.withDS ? (0, generate_ds_1.default)() : undefined,
                ...headers,
            },
            body: JSON.stringify(data),
            query: params,
        });
        if (statusCode !== 200) {
            throw new Error(`Request failed with status code ${statusCode}`);
        }
        const resData = await res.json();
        if (resData.retcode !== 0 && resData.retcode !== -5003) {
            const description = (0, error_2.default)(resData.retcode);
            throw new error_1.APIERROR(`${resData.message}`, resData.retcode, description);
        }
        return resData;
    }
    setLanguage(language) {
        this.language = language;
    }
}
exports.request = HTTPRequest;
